@@ -1,3 +1,4 @@
+import os
 import tensorflow as tf
 from tensorflow.keras.callbacks import Callback
 from tensorflow.keras import Model
@@ -6,6 +7,8 @@ import numpy as np
 from FastCNN.prx.PathProxy import PathProxy,PathProxy2
 from FastCNN.utils.Logs import tlog
 
+from IutyLib.file.files import CsvFile
+
 class MACallBack(Callback):
     train_acc_history = []
     valid_acc_history = []
@@ -22,6 +25,8 @@ class MACallBack(Callback):
         self.project_name = projectname
         self.model_tag = modeltag
         self.set_model(model)
+        
+        
         pass
     
     def saveLog(self,modelpath,value):
@@ -101,6 +106,10 @@ class MACallBack2(Callback):
         self.project_name = projectname
         self.model_tag = modeltag
         self.set_model(model)
+        
+        path = PathProxy2.getTrainProcessValues(projectname,modeltag)
+        tpv = CsvFile("tpv",os.path.dirname(path))
+        self.epcho = len(tpv.getData())
         pass
     
     def saveLog(self,modelpath,value):
@@ -114,7 +123,7 @@ class MACallBack2(Callback):
     
     def saveModelEpoch(modelpath,epoch):
         f = open(modelpath,'w')
-        f.write(str(epoch))
+        f.write(str(epoch+self.epcho))
         f.close()
         pass
     
